import os
import hashlib
import logging
import datetime

from django.utils.translation import ugettext as _

from django.core.exceptions import ObjectDoesNotExist, ValidationError
from django.http import HttpResponse
from django.shortcuts import render
from warpauth.ldap_connector import LDAPConnector
from warpzone.util import send_email

from warpauth.util import *
from warpauth.models import PasswordResetToken, LdapUser

from warpzone.settings import PW_RESET_TOKEN_LIFETIME

#
# Function to generate a password reset Token
#

def gen_token(request):
    if request.POST:
        try:
            usr = LdapUser.objects.get(uid=request.POST["username"])
            if usr.email == request.POST["email"]:
                p = PasswordResetToken()
                p.user = usr.uid
                p.email = usr.email
                p.hash = hashlib.sha1(os.urandom(128)).hexdigest()
                p.save()
                link = "https://infra.warpzone.ms/account/reset_password/%(hash)s" % {'hash': p.hash}
                ret = send_email(p.email, _("mail_subj_reset_password_token"), _("mail_content_reset_password_token %(link)s") % {'link': link} )
                if not ret:
                    page_context["error"] = _("err_sending_email")
        except Exception as e:
            pass
    else:
        pass
    return HttpResponse(render(request, 'warpauth/reset_password/token_gen.html', page_context))

#
# Function to change user password with a reset Token
#

def change_password(request, reset_hash=None):
    try:
        pw_reset_token = PasswordResetToken.objects.get(hash=reset_hash)
        time_difference = datetime.datetime.now() - pw_reset_token.created
        if time_difference.seconds/60 > int(PW_RESET_TOKEN_LIFETIME):
            pw_reset_token.delete()
            raise ValidationError("Token not valid")

        if request.POST:
            if request.POST["password"] != request.POST["password2"] or request.POST["password"] == "":
                page_context["error"] = _("err_passwords_not_matching")
            else:
                user = LdapUser.objects.get(uid=pw_reset_token.user)
                ldap_connector = LDAPConnector()
                ldap_connector.change_user_password(user.build_dn(), None, request.POST["password"], True)
                pw_reset_token.delete()
                send_password_change_notification(user)
        else:
            page_context["username"] = pw_reset_token.user

    except (ObjectDoesNotExist, ValidationError) as e:
        page_context["error"] = _("err_invalid_token")
        page_context["token_error"] = True

    return HttpResponse(render(request, 'warpauth/reset_password/change_password.html', page_context))
